@@ -4,13 +4,13 @@ use WWW::Mechanize;
 use HTML::TableExtract;
 use Encode qw/from_to/;
 use Encode::TW;
-use LWP::Charset qw(getCharset);
+use HTML::Encoding 'encoding_from_http_message';
 
 #---------------------------------------------------------------------------
 #  Variables
 #---------------------------------------------------------------------------
 
-our $VERSION = 0.02;
+use version; our $VERSION = qv('0.03');
 
 #---------------------------------------------------------------------------
 #  Methods
@@ -19,7 +19,7 @@ our $VERSION = 0.02;
 sub fetch {
 	my $b = WWW::Mechanize->new;
 	my $response = $b->get('http://www.schroders.com.tw');
-	my $current_encoding = getCharset($response);
+	my $current_encoding = encoding_from_http_message($response);
 
 	$b->get('http://schroders.moneydj.com/w/js/wfundjs.djjs?aspid=schroder&showall=0');
 	my $html = $b->content;
@@ -70,6 +70,12 @@ See L<Finance::QuoteTW>.
 
 Get fund quotes from www.schroders.com.tw
 
+=head1 FUNCTIONS
+
+=head2 fetch
+
+see L<Finance::QuoteTW>
+
 =head1 AUTHOR
 
 Alec Chen <alec@cpan.org>
